pub struct NodeCost {
pub node_id: String,
pub duration_ms: u64,
pub share: f64,
}Expand description
The node that dominated wall time, and by how much.
Fields
node_id: StringThe dominant node’s id.
duration_ms: u64Its total wall time in milliseconds.
This node’s share of all node compute time, in [0, 1].