pub struct GraphSummaryInfo {
pub n_nodes: usize,
pub node_ids: Vec<String>,
pub graph_path: Option<String>,
pub mermaid_path: Option<String>,
}Expand description
Compact description of the graph a run executed, with pointers to the full topology files inside the run directory.
Fields
n_nodes: usizeNumber of nodes in the executed graph.
node_ids: Vec<String>Node ids, in the graph’s insertion order.
graph_path: Option<String>Relative path to the serialized graph (e.g. graph.json).
mermaid_path: Option<String>Relative path to the mermaid rendering (e.g. graph.mmd).