Node

Struct Node 

pub struct Node {
    pub id: NodeId,
    pub label: String,
    pub kind: NodeKind,
}
A node in the computational graph.

Fields

id: NodeIdlabel: Stringkind: NodeKind

Implementations

Source

impl Node

pub fn new( id: impl Into<String>, label: impl Into<String>, filter_name: impl Into<String>, ) -> Self

Create a filter node (backward-compatible with old 3-arg constructor).

pub fn filter_with_id( id: impl Into<String>, filter_name: impl Into<String>, ) -> Self

Create a filter node with explicit id and filter_name.

pub fn filter(filter_name: impl Into<String>) -> Self

Create a filter node where id defaults to filter_name.

pub fn subgraph(id: impl Into<String>, graph: Graph) -> Self

Create a sub-graph node.

pub fn loop_node(id: impl Into<String>, max_iterations: Option<usize>) -> Self

Create a loop node.

pub fn branch(id: impl Into<String>) -> Self

Create a branch/conditional node.

pub fn filter_name(&self) -> Option<&str>

Get the filter name if this is a Filter node.