DataStore

Trait DataStore 

pub trait DataStore: Send + Sync {
    // Required methods
    fn put(&self, key: &CacheKey, data: &Value) -> Result<DataRef>;
    fn get(&self, data_ref: &DataRef) -> Result<Value>;
    fn exists(&self, data_ref: &DataRef) -> Result<bool>;
    fn remove(&self, data_ref: &DataRef) -> Result<()>;
    fn config(&self) -> &StorageConfig;

    // Provided methods
    fn get_rows(
        &self,
        data_ref: &DataRef,
        start: usize,
        len: usize,
    ) -> Result<Value> { ... }
    fn meta(&self, data_ref: &DataRef) -> Result<StoreMeta> { ... }
}
The DataStore trait: put/get/stream data across workers.

Unlike CacheStore (which stores Values by CacheKey), DataStore moves data between locations and supports streaming.

Required Methods

fn put(&self, key: &CacheKey, data: &Value) -> Result<DataRef>

Store data and return a reference to it.

fn get(&self, data_ref: &DataRef) -> Result<Value>

Retrieve data from a reference.

fn exists(&self, data_ref: &DataRef) -> Result<bool>

Check if data exists at a reference.

fn remove(&self, data_ref: &DataRef) -> Result<()>

Delete data at a reference.

fn config(&self) -> &StorageConfig

Get the storage config.

Provided Methods

fn get_rows( &self, data_ref: &DataRef, start: usize, len: usize, ) -> Result<Value>

Read a range of rows [start..start+len) from a tensor. Returns a Value::Tensor with shape[0] == len. Default impl downloads the full value and slices in memory.

fn meta(&self, data_ref: &DataRef) -> Result<StoreMeta>

Get metadata about a stored value without reading the data. Default impl downloads the full value to extract metadata.

Implementors